@@ -217,16 +217,18 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
     Examples
     --------
     >>> from tslearn.generators import random_walk_blobs
-    >>> X, y = random_walk_blobs(n_ts_per_blob=20, sz=64, d=2, n_blobs=2)
+    >>> X, y = random_walk_blobs(n_ts_per_blob=20, sz=64, d=2, n_blobs=3)
     >>> clf = ShapeletModel(n_shapelets_per_size={10: 5}, max_iter=1, verbose_level=0)
     >>> clf.fit(X, y).shapelets_.shape
     (5,)
     >>> clf.shapelets_[0].shape
     (10, 2)
     >>> clf.predict(X).shape
-    (40,)
+    (60,)
+    >>> clf.predict_proba(X).shape
+    (60, 3)
     >>> clf.transform(X).shape
-    (40, 5)
+    (60, 5)
     >>> params = clf.get_params(deep=True)
     >>> sorted(params.keys())
     ['batch_size', 'max_iter', 'n_shapelets_per_size', 'optimizer', 'random_state', 'verbose_level', 'weight_regularizer']
@@ -244,11 +246,11 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
     >>> clf2.shapelets_as_time_series_.shape
     (15, 20, 2)
     >>> clf2.predict(X).shape
-    (40,)
+    (60,)
     >>> clf2.transform(X).shape
-    (40, 15)
+    (60, 15)
     >>> clf2.locate(X).shape
-    (40, 15)
+    (60, 15)
     >>> import sklearn
     >>> cv_results = sklearn.model_selection.cross_validate(clf, X, y, return_train_score=False)
     >>> cv_results['test_score'].shape
@@ -331,8 +333,6 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
         if y.ndim == 1:
             self.label_binarizer = LabelBinarizer().fit(y)
             y_ = self.label_binarizer.transform(y)
-            # if y_.shape[1] == 1:
-            #     y_ = numpy.hstack((y_, 1 - y_))
         else:
             y_ = y
             self.categorical_y = True
@@ -349,7 +349,7 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
         self.transformer_model.compile(loss="mean_squared_error",
                                        optimizer=self.optimizer)
         self.locator_model.compile(loss="mean_squared_error",
-                                       optimizer=self.optimizer)
+                                   optimizer=self.optimizer)
         self._set_weights_false_conv(d=d)
         self.model.fit([X[:, :, di].reshape((n_ts, sz, 1)) for di in range(d)],
                        y_,
@@ -359,7 +359,7 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
         return self
 
     def predict(self, X):
-        """Predict class probability for a given set of time series.
+        """Predict class for a given set of time series.
 
         Parameters
         ----------
@@ -373,11 +373,7 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
             Index of the cluster each sample belongs to or class probability matrix, depending on
             what was provided at training time.
         """
-        X_ = to_time_series_dataset(X)
-        n_ts, sz, d = X_.shape
-        categorical_preds = self.model.predict([X_[:, :, di].reshape((n_ts, sz, 1)) for di in range(self.d)],
-                                               batch_size=self.batch_size,
-                                               verbose=self.verbose_level)
+        categorical_preds = self.predict_proba(X)
         if self.categorical_y:
             return categorical_preds
         else:
@@ -385,6 +381,26 @@ class ShapeletModel(BaseEstimator, ClassifierMixin):
                 categorical_preds = categorical_preds[:, 0]
             return self.label_binarizer.inverse_transform(categorical_preds)
 
+    def predict_proba(self, X):
+        """Predict class probability for a given set of time series.
+
+        Parameters
+        ----------
+        X : array-like of shape=(n_ts, sz, d)
+            Time series dataset.
+
+        Returns
+        -------
+        array of shape=(n_ts, n_classes),
+            Class probability matrix.
+        """
+        X_ = to_time_series_dataset(X)
+        n_ts, sz, d = X_.shape
+        categorical_preds = self.model.predict([X_[:, :, di].reshape((n_ts, sz, 1)) for di in range(self.d)],
+                                               batch_size=self.batch_size,
+                                               verbose=self.verbose_level)
+        return categorical_preds
+
     def transform(self, X):
         """Generate shapelet transform for a set of time series.
 
